==> driza-0.5.tar.gz: driza-0.5.0/Driza/operaciones/regresion.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#regresion.py Operación Regresión

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
from qt import *
from rpy import *
from Driza.widgets import wopciones

def funcion(dato,variable,cosa,opciones):  # Cambiar cosa por caso
	variable1 = variable[0].latin1() # Sin Qstring
	variable2 = variable[1].latin1() # Sin Qstring
	lista1=[int(x) for x in dato[variable1]]
	lista2=[int(x) for x in dato[variable2]]
	#resultadoprueba=r.lm(r("y ~ x"),data=r.data_frame(x=lista1, y=lista2))
	#sumario=r.summary_lm(resultadoprueba,True)
	resultadoprueba=r.lsfit(lista1,lista2)
	return resultadoprueba

def initresultado(resultado,opciones):
	"""Inicializa al objeto resultado, añadiendole lo que crea conveniente"""
	resultado.addTabla("resultado")
	resultado["resultado"].titulo=u"Regresión Lineal"
	lista=["m","b"]
	resultado["resultado"].settitulo(lista)


def interfazresultado(resultado,variables,caso,diccionario):
	"""Este método dice como introducir los datos en la tabla"""
	lista=[diccionario['coefficients']['X'],diccionario['coefficients']['Intercept']]
	resultado["resultado"].set(variables,caso,lista)

opciones=wopciones.WOpciones()
widget={"tipo":"CalculoDoble","opciones":opciones}

==> driza-0.5.2.tar.gz: driza-0.5.2/Driza/operaciones/regresion.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#regresion.py Operación Regresión

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
from qt import *
from rpy import *
from Driza.widgets import wopciones

def funcion(dato,variable,cosa,opciones):  # Cambiar cosa por caso
	variable1 = variable[0].latin1() # Sin Qstring
	variable2 = variable[1].latin1() # Sin Qstring
	lista1=[float(x) for x in dato[variable1]]
	lista2=[float(x) for x in dato[variable2]]
	#resultadoprueba=r.lm(r("y ~ x"),data=r.data_frame(x=lista1, y=lista2))
	#sumario=r.summary_lm(resultadoprueba,True)
	resultadoprueba=r.lsfit(lista1,lista2)
	return resultadoprueba

def initresultado(resultado,opciones):
	"""Inicializa al objeto resultado, añadiendole lo que crea conveniente"""
	resultado.addTablaDoble("resultado")
	resultado["resultado"].titulo=u"Regresión Lineal"
	lista=["m","b"]
	resultado["resultado"].settitulo(lista)


def interfazresultado(resultado,listaopciones):
	"""Este método dice como introducir los datos en la tabla"""
	variables=listaopciones[0]
	caso=listaopciones[1]
	diccionario=listaopciones[2]
	lista=[diccionario['coefficients']['X'],diccionario['coefficients']['Intercept']]
	resultado["resultado"].set(variables,caso,lista)

diccionarioopciones={}
widget={"tipo":"CalculoDoble","opciones":diccionarioopciones}
